import { ListFeatureParams, ListResponse, WarrantObject, ListPricingTierParams, CreateTenantParams, DeleteTenantParams, ListTenantParams, UpdateTenantParams, ListUserParams, Warrant, FeatureCheckParams } from "../types";
import Feature from "./Feature";
import PricingTier from "./PricingTier";
import User from "./User";
import { WarrantRequestOptions } from "../types/WarrantRequestOptions";
export default class Tenant implements WarrantObject {
    tenantId: string;
    meta?: {
        [key: string]: any;
    };
    constructor(tenantId: string, meta: {
        [key: string]: any;
    });
    static create(params?: CreateTenantParams, options?: WarrantRequestOptions): Promise<Tenant>;
    static batchCreate(params: CreateTenantParams[], options?: WarrantRequestOptions): Promise<Tenant[]>;
    static get(tenantId: string, options?: WarrantRequestOptions): Promise<Tenant>;
    static update(tenantId: string, params: UpdateTenantParams, options?: WarrantRequestOptions): Promise<Tenant>;
    static delete(tenantId: string, options?: WarrantRequestOptions): Promise<string>;
    static batchDelete(params: DeleteTenantParams[], options?: WarrantRequestOptions): Promise<string>;
    static listTenants(listParams?: ListTenantParams, options?: WarrantRequestOptions): Promise<ListResponse<Tenant>>;
    static listTenantsForUser(userId: string, listParams?: ListTenantParams, options?: WarrantRequestOptions): Promise<ListResponse<Tenant>>;
    listUsers(listParams?: ListUserParams, options?: WarrantRequestOptions): Promise<ListResponse<User>>;
    assignUser(userId: string, role: string, options?: WarrantRequestOptions): Promise<Warrant>;
    removeUser(userId: string, role: string, options?: WarrantRequestOptions): Promise<string>;
    listPricingTiers(listParams?: ListPricingTierParams, options?: WarrantRequestOptions): Promise<ListResponse<PricingTier>>;
    assignPricingTier(pricingTierId: string, options?: WarrantRequestOptions): Promise<Warrant>;
    removePricingTier(pricingTierId: string, options?: WarrantRequestOptions): Promise<string>;
    listFeatures(listParams?: ListFeatureParams, options?: WarrantRequestOptions): Promise<ListResponse<Feature>>;
    assignFeature(featureId: string, options?: WarrantRequestOptions): Promise<Warrant>;
    removeFeature(featureId: string, options?: WarrantRequestOptions): Promise<string>;
    hasFeature(params: FeatureCheckParams, options?: WarrantRequestOptions): Promise<boolean>;
    getObjectType(): string;
    getObjectId(): string;
}
